class Redland < Formula
  desc "RDF Library"
  homepage "https://librdf.org/"
  url "https://download.librdf.org/source/redland-1.0.17.tar.gz"
  sha256 "de1847f7b59021c16bdc72abb4d8e2d9187cd6124d69156f3326dd34ee043681"
  license any_of: ["LGPL-2.1-or-later", "GPL-2.0-or-later", "Apache-2.0"]
  revision 1

  livecheck do
    url :homepage
    regex(/href=.*?redland[._-]v?(\d+(?:\.\d+)+)\.t/i)
  end

  depends_on "pkg-config" => :build
  depends_on "raptor"
  depends_on "rasqal"
  depends_on "sqlite"
  depends_on "unixodbc"

  resource "bindings" do
    url "https://download.librdf.org/source/redland-bindings-1.0.17.1.tar.gz"
    sha256 "ff72b587ab55f09daf81799cb3f9d263708fad5df7a5458f0c28566a2563b7f5"
  end

  # Fix -flat_namespace being used on Big Sur and later.
  patch do
    url "https://raw.githubusercontent.com/Homebrew/formula-patches/03cf8088210822aa2c1ab544ed58ea04c897d9c4/libtool/configure-pre-0.4.2.418-big_sur.diff"
    sha256 "83af02f2aa2b746bb7225872cab29a253264be49db0ecebb12f841562d9a2923"
  end

  def install
    system "./configure", "--disable-debug",
                          "--disable-dependency-tracking",
                          "--prefix=#{prefix}",
                          "--with-bdb=no",
                          "--with-mysql=no",
                          "--with-sqlite=yes"
    system "make", "install"
  end

  test do
    (testpath/"test.c").write <<~EOS
      #include <stdio.h>
      #include <redland.h>

      int main(int argc, char *argv[]) {
        librdf_world* world;
        librdf_storage* storage;
        librdf_model* model;
        librdf_statement *statement;

        world = librdf_new_world();
        librdf_world_open(world);
        storage = librdf_new_storage(world, "file", "file.rdf", NULL);
        model = librdf_new_model(world, storage, NULL);
        statement = librdf_new_statement_from_nodes(
          world,
          librdf_new_node_from_uri_string(world, (const unsigned char*) "https://example.org/"),
          librdf_new_node_from_uri_string(world, (const unsigned char*) "http://purl.org/dc/elements/1.1/title"),
          librdf_new_node_from_literal(world, (const unsigned char*) "Homebrew was here", NULL, 0)
        );

        librdf_model_add_statement(model, statement);
        librdf_free_statement(statement);
        librdf_free_model(model);
        librdf_free_storage(storage);
        librdf_free_world(world);

        return 0;
      }
    EOS

    (testpath/"file.rdf").write <<~EOS
      <?xml version="1.0"?>
      <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
          xmlns:dc="http://purl.org/dc/elements/1.1/">
        <rdf:Description rdf:about="https://example.org">
          <dc:title>Example Site</dc:title>
          <dc:creator>Internet Assigned Numbers Authority</dc:creator>
          <dc:description>
            This domain is for use in illustrative examples in documents.
            You may use this domain in literature without prior coordination or asking for permission.
          </dc:description>
        </rdf:Description>
      </rdf:RDF>
    EOS

    includes = %W[
      -I#{include}
      -I#{Formula["raptor"].opt_include}/raptor2
      -I#{Formula["rasqal"].opt_include}/rasqal
    ]

    libs = %W[
      -L#{lib}
      -L#{Formula["raptor"].opt_lib}
      -L#{Formula["rasqal"].opt_lib}
      -lrdf -lraptor2 -lrasqal
    ]

    system ENV.cc, *includes, "test.c", *libs, "-o", "test"
    system testpath/"test"

    expected = <<~EOS
      #{" " * 2}<rdf:Description rdf:about="https://example.org/">
      #{" " * 4}<ns0:title xmlns:ns0="http://purl.org/dc/elements/1.1/">Homebrew was here</ns0:title>
      #{" " * 2}</rdf:Description>
    EOS
    assert_match expected, (testpath/"file.rdf").read
  end
end
